@@ -25,7 +25,7 @@ if not hasattr(__builtin__, '_'):
     def _(string):
         return string
 
-version =           '1.1.2'
+version =           '1.1.6'
 author =            'Jendrik Seipp'
 authorMail =        'jendrikseipp@web.de'
 url =               'http://rednotebook.sourceforge.net'
@@ -35,10 +35,10 @@ bug_url =           'https://bugs.launchpad.net/rednotebook/+filebug'
 
 developers =    ['Jendrik Seipp <jendrikseipp@web.de>',
                 '',
-                'Contributors:',
+                'Past Contributors:',
                 'Alexandre Cucumel <superkiouk@gmail.com>',
                 ]
-                
+
 comments = '''\
 RedNotebook is a graphical journal to keep track of notes and \
 thoughts. It includes a calendar navigation, customizable \
@@ -47,7 +47,7 @@ format, tag and search your entries.\
 '''
 
 license_text = '''\
-Copyright (c) 2009,2010  Jendrik Seipp
+Copyright (c) 2009,2010,2011  Jendrik Seipp
 
 RedNotebook is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -76,8 +76,24 @@ If the journal-path is omitted the last session's journal will be used.
 At the first program start this defaults to "$HOME/.rednotebook/data".
 ''' % version
 
-greeting = _('''Hello,
-this is RedNotebook, a desktop journal. Thank you very much for giving it a try.''')
+ideas = _('Ideas')
+tags = _('Tags')
+cool_stuff = _('Cool Stuff')
+movies = _('Movies')
+work = _('Work')
+free_time = _('Free time')
+documentation = _('Documentation')
+todo = _('Todo')
+done = _('Done')
+rtm = _('Remember the milk')
+dishes = _('Wash the dishes')
+check_mail = _('Check mail')
+
+greeting = _('Hello!')
+intro=_('''Some example text has been added to help you start and \
+you can erase it whenever you like.''')
+### Translators: "Help" -> noun
+help_par = _('The example text and more documentation is available under "Help" -> "Contents".')
 overview1 = _('The interface is divided into three parts:')
 ### Translators: The location "left"
 overview21 = _('Left')
@@ -89,18 +105,25 @@ overview32 = _('Text for a day')
 overview41 = _('Right')
 overview42 = _('Annotations to a day')
 
-text_entry = _('Text entries')
-text_entry_par = _('An entry could look like this:')
+### Translators: noun
+preview = _('Preview')
+preview1 = _('''There are two modes in RedNotebook, the __edit__ mode and \
+the __preview__ mode.''')
+### Translators: Preview -> noun
+preview2 = _('Click on Preview above to see the difference.')
+preview_par = ' '.join([preview1, preview2])
+
 example_entry = _('''Today I went to the //pet shop// and bought a **tiger**. Then we went to the \
 --pool-- park and had a nice time playing \
 ultimate frisbee. Afterwards we watched "__Life of Brian__".''')
 
 annotations = _('Annotations')
-ann1 = _('On the right there is space for annotations to a day.')
-ann2 = _('Annotations are notes that can easily be sorted into categories.')
+ann2 = _('Annotations are notes that can be sorted into categories.')
 ann3 = _('''For example you could create the category "Ideas" \
 and then add today's ideas to it.''')
-ann_par = ' '.join([ann1, ann2, ann3])
+ann4 = _('If you find annotations confusing you can simply hide them for '
+         'now by moving the separator to the far right.')
+ann_par = ' '.join([ann2, ann3, ann4])
 
 templates = ('Templates')
 temp1 = ('RedNotebook supports templates.')
@@ -119,21 +142,15 @@ save4 = _('In the "Journal" menu you also find the "Export" button.')
 save5 = _('Click on "Export" and export your diary to Plain Text, HTML or Latex.')
 save_par = ' '.join([save1, save2, save3, save4, save5])
 
-### Translators: noun
-help = _('Help')
-### Translators: "Help" -> noun
-help3 = _('You can find more documentation under "Help" -> "Help".')
-help_par = ' '.join([help3])
-
 error1 = _('If you encounter any errors, please drop me a note so I can fix them.')
 error2 = _('Any feedback is appreciated.')
 error_par = ' '.join([error1, error2])
 
 goodbye_par = _('Have a nice day!')
 
-
 completeWelcomeText = '''\
-%(greeting)s
+%(greeting)s %(intro)s %(help_par)s
+
 %(overview1)s
 
 - **%(overview21)s**: %(overview22)s
@@ -141,10 +158,8 @@ completeWelcomeText = '''\
 - **%(overview41)s**: %(overview42)s
 
 
-=== %(text_entry)s ===
-%(text_entry_par)s
-
-%(example_entry)s
+=== %(preview)s ===
+%(preview_par)s
 
 === %(annotations)s ===
 %(ann_par)s
@@ -152,18 +167,16 @@ completeWelcomeText = '''\
 === %(save)s ===
 %(save_par)s
 
-=== %(help)s ===
-%(help_par)s
-
 %(error_par)s
 
 %(goodbye_par)s''' % globals()
 
+
 welcome_day = {'text': completeWelcomeText,
-u'Cool Stuff': {u'Ate **two** cans of spam': None},
-_(u'Ideas'): {_(u'Use a cool journal app'): None},
-u'Movies': {u"Monty Python's Life of Brian": None},
-u'Tags': {u'Work': None, u'Documentation': None},
+cool_stuff: {_('Ate **two** cans of spam'): None},
+ideas: {_('Use a cool journal app'): None},
+movies: {_("Monty Python's Life of Brian"): None},
+tags: {documentation: None},
 }
 
 example_day1 = {
@@ -171,10 +184,8 @@ example_day1 = {
 === Annotations in Categories ===
 %(ann_par)s
 
-- Ideas
-  - Invent Anti-Hangover-Machine
-- Movies
-  - Monty Python and the Holy Grail
+- %(todo)s
+  - %(dishes)s
 
 
 The name "Categories" is a little bit confusing. It does not mean that a day is \
@@ -182,53 +193,59 @@ put into a category, but that there is additional content on the right, \
 sorted into categories. A category will contain several notes distributed over various days.
 
 For example you could want to remember all the movies you watch. \
-Each time you watch a new one, add the category "Movies" with the \
+Each time you watch a new one, add the category "%(movies)s" with the \
 entry "Name of the movie" to the day.
 
 I’ll give you another example: I like to maintain a list of cool things I have done. \
 So if I did a cool thing on some day, I navigate to that day and add the category \
-"Cool Stuff" with the entry "Visit the pope" (Sadly I haven’t done that, yet ;-) ). \
-When I have done more cool things on many days, they all have a category "Cool Stuff" \
+"%(cool_stuff)s" with the entry "Visit the pope" (Sadly I haven’t done that, yet ;-) ). \
+When I have done more cool things on many days, they all have a category "%(cool_stuff)s" \
 and many different entries. It is possible to export only that category and \
 get a list of the cool stuff that happened to me with the respective dates.
 
-Additionally you can select the "Cool Stuff" category in the word cloud window \
+Additionally you can select the "%(cool_stuff)s" category in the word cloud window \
 to get a list of all the cool things.
 
-Maybe a good thing to know is the following: 
-"Tags" is a category, the tagnames are entries in the category "Tags", \
-distributed over various days. 
-Similarly you can have a category "Movies" and add it together with \
+Maybe a good thing to know is the following:
+"%(tags)s" is a category, the tagnames are entries in the category "%(tags)s", \
+distributed over various days.
+Similarly you can have a category "%(movies)s" and add it together with \
 the movie's name to every day on which you see a new film.
 
 Category entries can have all of the formatting that the main text supports, \
 so e.g. you can add bold text, links or images.''' % globals(),
-u'Cool Stuff': {u'Went to see the pope': None},
-u'Ideas': {u'Invent Anti-Hangover-Machine': None},
-u'Movies': {u'Monty Python and the Holy Grail': None},
-u'Tags': {u'Documentation': None, u'Projects': None},
-u'Todo': {u'**Wash the dishes**': None},
+cool_stuff: {_('Went to see the pope'): None},
+ideas: {_('Invent Anti-Hangover-Machine'): None},
+movies: {_('Monty Python and the Holy Grail'): None},
+tags: {documentation: None},
+todo: {'**%s**' % dishes: None},
 }
 
-example_day2 = {
-'text': '''\
+multiple_entries_text = '''\
 === Multiple Entries ===
 You can add multiple entries to one day in two ways:
-- Use two different journals (one named “Work”, the other “Play”)
-- Separate your two entries by different titles (===Work===, ===Play===)
+- Use two different journals (one named "%(work)s", the other "%(free_time)s")
+- Separate your two entries by different titles (===%(work)s===, ===%(free_time)s===)
 - Use a horizontal separator line (20 “=”s)
 
 
+''' % globals()
+
+multiple_entries_example = '''\
 ====================
 
-=== Work ===
+=== %(work)s ===
 Here goes the first entry.
 
 ====================
 
-=== Play ===
-Here comes the entry about the fun stuff.''',
-u'Tags': {u'Documentation': None, u'Work': None, u'Play': None},}
+=== %(free_time)s ===
+Here comes the entry about the fun stuff.
+''' % globals()
+
+example_day2 = {
+'text': multiple_entries_text + multiple_entries_example,
+tags: {documentation: None, work: None, free_time: None},}
 
 example_day3 = {
 'text': '''\
@@ -239,18 +256,18 @@ on one day and it remains there until you delete it.
 
 Here is how it works:
 - On the right click on "New Entry"
-- Fill "Todo" and "Remember the milk" in the fields and hit "OK"
+- Fill "%(todo)s" and "Remember the milk" in the fields and hit "OK"
 - Select the categories cloud from the drop down menu on the left
-- Now you can click on "todo" and see all your todo items
+- Now you can click on "%(todo)s" and see all your todo items
 
 
 - To tick off a todo item you can strike it out by adding "--" around the item.
 - To mark an item as important, add "**" around it.
 
 
-So --Remember the milk-- becomes struck through and **Wash the dishes** becomes bold.
+So --%(rtm)s-- becomes struck through and **%(dishes)s** becomes bold.
 
-You can see all your todo items at once by clicking "todo" in the category cloud \
+You can see all your todo items at once by clicking "%(todo)s" in the category cloud \
 on the left. There you can also \
 group your todo items into important and finished items by hitting "Entry" \
 at the top of the list.
@@ -259,25 +276,29 @@ It probably sometimes makes sense to add the todo items to the day you want to \
 have completed them (deadline day).
 
 Once you've finished an item, you could also change its category name from \
-"Todo" to "Done".''',
-u'Tags': {u'Documentation': None,},
-u'Todo': {u'--Remember the milk--': None,
-        u'Take a break': None},
-u'Done': {u'--Check mail--': None,},
+"%(todo)s" to "%(done)s".''' % globals(),
+tags: {documentation: None,},
+todo: {u'--%s--' % rtm: None,
+       u'**%s**' % dishes: None},
+done: {u'--%s--' % check_mail: None,},
 }
 
 example_content = [welcome_day, example_day1, example_day2, example_day3]
 
 ann_help_text = example_day1['text'].replace('===', '==')
-
-multiple_entries_text = example_day2['text']
-multiple_entries_text = multiple_entries_text.replace('=== Work ===', '**Work**\n')
-multiple_entries_text = multiple_entries_text.replace('=== Play ===', '**Play**\n')
-
 todo_help_text = example_day3['text']
 
 
 help_text = '''
+== Layout ==
+%(overview1)s
+- **%(overview21)s**: %(overview22)s
+- **%(overview31)s**: %(overview32)s
+- **%(overview41)s**: %(overview42)s
+
+
+%(preview1)s
+
 == Text ==
 The main text field is the container for your normal diary entries like this one:
 
@@ -286,7 +307,7 @@ The main text field is the container for your normal diary entries like this one
 == Format ==
 As you see, the text can be formatted **bold**, \
 //italic//, --struck through-- and __underlined__. As a convenience there \
-is also the "Format" button, with which you can format the main text and nodes \
+is also the "Format" button, with which you can format the main text and entries \
 in the categories tree on the right.
 
 A blank line starts a new **paragraph**, two backslashes\\\\ result in a **newline**.
@@ -295,7 +316,7 @@ To see the result, click on the "Preview" button.
 You can also see how \
 this text was formatted by looking at its [source source.txt].
 
-**Lists** can be created by using the following style, If you use "+" 
+**Lists** can be created by using the following style, If you use "+"
 instead of "-" you can create a **numbered list**.
 
 ```
@@ -318,7 +339,7 @@ With the insert button you cannot insert **links to directories** on your comput
 Those can be inserted manually however (""[Home ""file:///home/""]"").
 
 == %(templates)s ==
-%(temp_par)s 
+%(temp_par)s
 The files 1.txt to 7.txt in the template directory correspond to the templates \
 for each day of the week. The current weekday's template will be filled \
 into the text area when you click on "Template". You can open the template files \
@@ -370,7 +391,7 @@ open this dialog by clicking on the entry in the "Edit" menu.
 Since version 0.9.2 you can also directly export your journal to PDF. If the \
 option does not show up in the export assistant, you need to install \
 pywebkitgtk version 1.1.5 or later (the package is sometime called \
-python-webkit). 
+python-webkit).
 
 **Latex caveats**
 
@@ -428,7 +449,7 @@ RedNotebook can be run in portable mode. In this mode, the \
 template directory and the configuration and log file are saved \
 in the application directory instead of in the home directory. \
 Additionally the path to the last opened journal is remembered \
-relatively to the application directory. 
+relatively to the application directory.
 
 To use RedNotebook on a flash drive on Windows, run the installer and \
 select a directory on your USB drive as the installation directory. \
@@ -526,16 +547,23 @@ On Linux, start a terminal and call ``LANG=de_DE.utf8``. Then in the \
 same terminal, run ``rednotebook``. The language change will be gone \
 however once you close the terminal.
 
-On Windows, set or create a PATH environment variable with the desired \
-code.
+On Windows, set or create a LANG environment variable with the desired \
+code:
+
++ Right-click My Computer and click Properties.
++ In the System Properties window, click on the Advanced tab.
++ In the Advanced section, click the Environment Variables button.
++ Click the New button and insert LANG at the top and e.g. de or de_DE or
+  de_DE.UTF-8 (use your [language code ""http://en.wikipedia.org/wiki/ISO_639-1""]).
+
 
 === Titles ===
 You can insert titles into your post by adding "="s around your title
-text. = My Title = is the biggest heading, ====== My Title ====== is 
-the smallest heading. A title line can only contain the title, nothing 
+text. = My Title = is the biggest heading, ====== My Title ====== is
+the smallest heading. A title line can only contain the title, nothing
 else.
 
-Numbered titles can be created by using "+" instead of "=". 
+Numbered titles can be created by using "+" instead of "=".
 ""+ My Title +"" produces a title like "1.", ++++++ My Title ++++++
 produces a title like 0.0.0.0.0.1
 
@@ -623,7 +651,7 @@ The directory name is used as a name for the journal.
 
 In the directory there are several files all conforming to the naming \
 scheme "2010-05.txt" (<year>-<month>.txt). Obviously these files \
-correspond to months (May 2010). 
+correspond to months (May 2010).
 
 Each month file contains text for the days of that month. \
 The text is actually [YAML www.yaml.org] markup. Without the \
