@@ -1,17 +1,17 @@
 # -*- coding: utf-8 -*-
 # -----------------------------------------------------------------------
 # Copyright (c) 2009  Jendrik Seipp
-# 
+#
 # RedNotebook is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
 # (at your option) any later version.
-# 
+#
 # RedNotebook is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-# 
+#
 # You should have received a copy of the GNU General Public License along
 # with RedNotebook; if not, write to the Free Software Foundation, Inc.,
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
@@ -49,7 +49,7 @@ if not main_is_frozen():
     app_dir = os.path.normpath(app_dir)
 else:
     app_dir = get_main_dir()
-    
+
 
 
 image_dir = os.path.join(app_dir, 'images')
@@ -71,31 +71,28 @@ class Filenames(dict):
                 value = os.path.abspath(value)
                 self[key] = value
                 setattr(self, key, value)
-        
+
         self.portable = bool(config.read('portable', 0))
-        
+
         self.journal_user_dir = self.get_user_dir(config)
-        
+
         self.data_dir = self.default_data_dir
-        
-        # Is this the first run of RedNotebook?
-        self.is_first_start = not os.path.exists(self.journal_user_dir)
-            
+
         # Assert that all dirs and files are in place so that logging can take start
         make_directories([self.journal_user_dir, self.data_dir, self.template_dir,
                         self.temp_dir])
         make_files([(self.config_file, ''), (self.log_file, '')])
-        
+
         self.last_pic_dir = self.user_home_dir
         self.last_file_dir = self.user_home_dir
-        
-        
+
+
     def get_user_dir(self, config):
         custom = config.read('userDir', '')
-        
+
         if custom:
             # If a custom user dir has been set,
-            # construct the absolute path (if not absolute already) 
+            # construct the absolute path (if not absolute already)
             # and use it
             if not os.path.isabs(custom):
                 custom = os.path.join(self.app_dir, custom)
@@ -105,10 +102,10 @@ class Filenames(dict):
                 user_dir = os.path.join(self.app_dir, 'user')
             else:
                 user_dir = os.path.join(self.user_home_dir, '.rednotebook')
-        
+
         return user_dir
-        
-        
+
+
     def __getattribute__(self, attr):
         user_paths = dict((('template_dir', 'templates'),
                         ('temp_dir', 'tmp'),
@@ -116,42 +113,41 @@ class Filenames(dict):
                         ('config_file', 'configuration.cfg'),
                         ('log_file', 'rednotebook.log'),
                         ))
-                            
+
         if attr in user_paths:
             return os.path.join(self.journal_user_dir, user_paths.get(attr))
-        
+
         return dict.__getattribute__(self, attr)
-        
-        
-        
+
+
+
 def read_file(filename):
-    '''
-    Tries to read a given file
-    
+    '''Tries to read a given file
+
     Returns None if an error is encountered
     '''
-    encodings = ['utf-8']#, 'latin1', 'latin2']
-    
+    encodings = ['utf-8']
+
     try:
         import chardet
     except ImportError:
-        logging.info("chardet not found. Let's hope all your files are unicode")
+        logging.info("chardet not found. 'utf-8' encoding will be assumed")
         chardet = None
-        
-    if chardet:
+
+    if False and chardet:
         with open(filename, 'rb') as file:
             content = file.read()
         guess = chardet.detect(content)
         logging.info('Chardet guesses %s for %s' % (guess, filename))
         encoding = guess.get('encoding')
-        
+
         # chardet makes errors here sometimes
         if encoding in ['MacCyrillic', 'ISO-8859-7']:
             encoding = 'ISO-8859-2'
-            
+
         if encoding:
             encodings.insert(0, encoding)
-    
+
     # Only check the first encoding
     for encoding in encodings[:1]:
         try:
@@ -166,8 +162,8 @@ def read_file(filename):
         except Exception, e:
             logging.error(e)
     return ''
-    
-    
+
+
 def write_file(filename, content):
     assert os.path.isabs(filename)
     #print 'CONTENT', type(content), repr(content)
@@ -175,40 +171,34 @@ def write_file(filename, content):
         # Turn content into unicode string
     #    content = content.decode('utf-8')
     try:
-        with codecs.open(filename, 'wb', errors='replace') as file:
+        with codecs.open(filename, 'wb', errors='replace', encoding='utf-8') as file:
         #with open(filename, 'wb') as file:
             file.write(content)
-            file.flush()
-            file.close()
     except IOError, e:
         logging.error('Error while writing to "%s": %s' % (filename, e))
-    
 
 
 def make_directory(dir):
     if not os.path.exists(dir):
         os.makedirs(dir)
-        
+
 def make_directories(dirs):
     for dir in dirs:
         make_directory(dir)
-        
+
 def make_file(file, content=''):
     if not os.path.exists(file):
         write_file(file, content)
-            
+
 def make_files(file_content_pairs):
     for file, content in file_content_pairs:
-        if len(content) > 0:
-            make_file(file, content)
-        else:
-            make_file(file)
-            
+        make_file(file, content)
+
 def make_file_with_dir(file, content):
     dir = os.path.dirname(file)
     make_directory(dir)
     make_file(file, content)
-    
+
 def get_relative_path(from_dir, to_dir):
     '''
     Try getting the relative path from from_dir to to_dir
@@ -220,18 +210,18 @@ def get_relative_path(from_dir, to_dir):
         # return absolute path to to_dir
         drive1, tail = os.path.splitdrive(from_dir)
         drive2, tail = os.path.splitdrive(to_dir)
-        
+
         # drive1 and drive2 are always empty strings on Unix
         if not drive1.upper() == drive2.upper():
             return to_dir
-        
+
         return os.path.relpath(to_dir, from_dir)
     else:
         return to_dir
-    
+
 def write_archive(archive_file_name, files, base_dir='', arc_base_dir=''):
     """
-    use base_dir for relative filenames, in case you don't 
+    use base_dir for relative filenames, in case you don't
     want your archive to contain '/home/...'
     """
     archive = zipfile.ZipFile(archive_file_name, "w")
@@ -253,7 +243,7 @@ def get_journal_title(dir):
     dir = os.path.abspath(dir)
     # Remove double slashes and last slash
     dir = os.path.normpath(dir)
-    
+
     dirname, basename = os.path.split(dir)
     # Return "/" if journal is located at /
     return basename or dirname
@@ -263,36 +253,36 @@ def get_platform_info():
     import platform
     import gtk
     import yaml
-    
-    functions = [platform.machine, platform.platform, platform.processor, \
+
+    functions = [platform.machine, platform.platform, platform.processor,
                 platform.python_version, platform.release, platform.system,]
     values = map(lambda function: function(), functions)
     functions = map(lambda function: function.__name__, functions)
     names_values = zip(functions, values)
-    
+
     lib_values = [('GTK version', gtk, 'gtk_version'),
                     ('PyGTK version', gtk, 'pygtk_version'),
                     ('Yaml version', yaml, '__version__'),]
-    
+
     for name, object, value in lib_values:
         try:
             names_values.append((name, getattr(object, value)))
         except AttributeError, err:
             logging.info('%s could not be determined' % name)
-            
+
     vals = ['%s: %s' % (name, val) for name, val in names_values]
     return 'System info: ' + ', '.join(vals)
-    
+
 
 def system_call(args):
     '''
     Asynchronous system call
-    
+
     subprocess.call runs synchronously
     '''
     subprocess.Popen(args)
-    
-    
+
+
 def get_local_url(url):
     '''
     Sanitize url, make it absolute and normalize it, then add file://(/) scheme
@@ -303,12 +293,14 @@ def get_local_url(url):
     if url.startswith('file://'):
         url = url.replace('file://', '')
     url = os.path.normpath(url)
-    
+
+    import urllib
+    url = urllib.unquote(url).decode('utf-8')
     scheme = 'file:///' if sys.platform == 'win32' else 'file://'
     url = scheme + url
     logging.debug('Transformed local URI %s to %s' % (orig_url, url))
     return url
-    
+
 
 def open_url_in_browser(url):
     try:
@@ -316,7 +308,7 @@ def open_url_in_browser(url):
         webbrowser.open(url)
     except webbrowser.Error:
         logging.exception('Failed to open web browser')
-     
+
 
 def open_url(url):
     '''
@@ -325,7 +317,7 @@ def open_url(url):
     if url.startswith('http'):
         open_url_in_browser(url)
         return
-        
+
     # Try opening the file locally
     if sys.platform == 'win32':
         try:
@@ -337,7 +329,7 @@ def open_url(url):
             return
         except (WindowsError, OSError):
             logging.exception('Opening %s with "os.startfile" failed' % url)
-    
+
     elif sys.platform == 'darwin':
         try:
             logging.info('Trying to open %s with "open"' % url)
@@ -345,7 +337,7 @@ def open_url(url):
             return
         except OSError, subprocess.CalledProcessError:
             logging.exception('Opening %s with "open" failed' % url)
-    
+
     else:
         try:
             subprocess.check_call(['xdg-open', '--version'])
@@ -354,12 +346,12 @@ def open_url(url):
             return
         except OSError, subprocess.CalledProcessError:
             logging.exception('Opening %s with xdg-open failed' % url)
-        
+
     # If everything failed, try the webbrowser
     open_url_in_browser(url)
-    
-        
-    
+
+
+
 if __name__ == '__main__':
     dirs = ['/home/my journal', '/my journal/', r'C:\\Dok u E\journal',
             '/home/name/journal', '/']
